==> jc-1.4.0.tar.gz: polyglot/types/reflect/Exceptions.h <==
// class polyglot.types.reflect.Exceptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d931fb91b452174 polyglot_types_reflect_Attribute
// @dep_class a0635b021c46faf6 polyglot_types_reflect_Exceptions

// header file dependencies
// @dep_header polyglot_types_reflect_Attribute

#include "polyglot/types/reflect/Attribute.h"

#ifndef _JC_polyglot_types_reflect_Exceptions_H_
#define _JC_polyglot_types_reflect_Exceptions_H_

// Forward structure declarations
struct _jc_java_io_DataInputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_polyglot_types_reflect_ClassFile$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_Exceptions$sub_refs	_jc_polyglot_types_reflect_Exceptions$sub_refs;
typedef struct _jc_polyglot_types_reflect_Exceptions$sub_nonrefs	_jc_polyglot_types_reflect_Exceptions$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_Exceptions$refs	_jc_polyglot_types_reflect_Exceptions$refs;
typedef struct _jc_polyglot_types_reflect_Exceptions$nonrefs	_jc_polyglot_types_reflect_Exceptions$nonrefs;
typedef struct _jc_polyglot_types_reflect_Exceptions$object	_jc_polyglot_types_reflect_Exceptions$object;

typedef const struct _jc_polyglot_types_reflect_Exceptions$vmethods	_jc_polyglot_types_reflect_Exceptions$vmethods;
typedef const struct _jc_polyglot_types_reflect_Exceptions$vtable	_jc_polyglot_types_reflect_Exceptions$vtable;
typedef const struct _jc_polyglot_types_reflect_Exceptions$vtype	_jc_polyglot_types_reflect_Exceptions$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_Exceptions$method$_init$9b2396520a599d56(_jc_env *, struct _jc_polyglot_types_reflect_Exceptions$object *, struct _jc_polyglot_types_reflect_ClassFile$object *, jint, struct _jc_int_array *);
extern void _jc_polyglot_types_reflect_Exceptions$method$_init$265bd2c7200cac08(_jc_env *, struct _jc_polyglot_types_reflect_Exceptions$object *, struct _jc_polyglot_types_reflect_ClassFile$object *, struct _jc_java_io_DataInputStream$object *, jint, jint);

// Virtual methods structure
struct _jc_polyglot_types_reflect_Exceptions$vmethods {
};

// Vtable
struct _jc_polyglot_types_reflect_Exceptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_Attribute$vmethods	polyglot_types_reflect_Attribute;
	_jc_polyglot_types_reflect_Exceptions$vmethods	polyglot_types_reflect_Exceptions;
};

// Vtype
struct _jc_polyglot_types_reflect_Exceptions$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_Exceptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Exceptions$sub_refs {
	_jc_int_array	*exceptions;
	struct _jc_polyglot_types_reflect_ClassFile$object	*clazz;
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_Exceptions$refs {
    _jc_polyglot_types_reflect_Exceptions$sub_refs	polyglot_types_reflect_Exceptions;
    _jc_polyglot_types_reflect_Attribute$sub_refs	polyglot_types_reflect_Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Exceptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_Exceptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_Attribute$sub_nonrefs	polyglot_types_reflect_Attribute;
    _jc_polyglot_types_reflect_Exceptions$sub_nonrefs	polyglot_types_reflect_Exceptions;
};

// Object instance structure
struct _jc_polyglot_types_reflect_Exceptions$object {
	_jc_polyglot_types_reflect_Exceptions$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_Exceptions$vtype	*vtype;
	_jc_polyglot_types_reflect_Exceptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_Exceptions$vtype _jc_polyglot_types_reflect_Exceptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_Exceptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_Exceptions$class_object;

#endif	/* _JC_polyglot_types_reflect_Exceptions_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/reflect/Exceptions.h <==
// class polyglot.types.reflect.Exceptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d931fb91b452174 polyglot_types_reflect_Attribute
// @dep_class a0635b021c46faf6 polyglot_types_reflect_Exceptions

// header file dependencies
// @dep_header polyglot_types_reflect_Attribute

#include "polyglot/types/reflect/Attribute.h"

#ifndef _JC_polyglot_types_reflect_Exceptions_H_
#define _JC_polyglot_types_reflect_Exceptions_H_

// Forward structure declarations
struct _jc_java_io_DataInputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_polyglot_types_reflect_ClassFile$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_Exceptions$sub_refs	_jc_polyglot_types_reflect_Exceptions$sub_refs;
typedef struct _jc_polyglot_types_reflect_Exceptions$sub_nonrefs	_jc_polyglot_types_reflect_Exceptions$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_Exceptions$refs	_jc_polyglot_types_reflect_Exceptions$refs;
typedef struct _jc_polyglot_types_reflect_Exceptions$nonrefs	_jc_polyglot_types_reflect_Exceptions$nonrefs;
typedef struct _jc_polyglot_types_reflect_Exceptions$object	_jc_polyglot_types_reflect_Exceptions$object;

typedef const struct _jc_polyglot_types_reflect_Exceptions$vmethods	_jc_polyglot_types_reflect_Exceptions$vmethods;
typedef const struct _jc_polyglot_types_reflect_Exceptions$vtable	_jc_polyglot_types_reflect_Exceptions$vtable;
typedef const struct _jc_polyglot_types_reflect_Exceptions$vtype	_jc_polyglot_types_reflect_Exceptions$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_Exceptions$method$_init$9b2396520a599d56(_jc_env *, struct _jc_polyglot_types_reflect_Exceptions$object *, struct _jc_polyglot_types_reflect_ClassFile$object *, jint, struct _jc_int_array *) _JC_JCNI_ATTR;
extern void _jc_polyglot_types_reflect_Exceptions$method$_init$265bd2c7200cac08(_jc_env *, struct _jc_polyglot_types_reflect_Exceptions$object *, struct _jc_polyglot_types_reflect_ClassFile$object *, struct _jc_java_io_DataInputStream$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_types_reflect_Exceptions$vmethods {
};

// Vtable
struct _jc_polyglot_types_reflect_Exceptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_Attribute$vmethods	polyglot_types_reflect_Attribute;
	_jc_polyglot_types_reflect_Exceptions$vmethods	polyglot_types_reflect_Exceptions;
};

// Vtype
struct _jc_polyglot_types_reflect_Exceptions$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_Exceptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Exceptions$sub_refs {
	_jc_int_array	*exceptions;
	struct _jc_polyglot_types_reflect_ClassFile$object	*clazz;
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_Exceptions$refs {
    _jc_polyglot_types_reflect_Exceptions$sub_refs	polyglot_types_reflect_Exceptions;
    _jc_polyglot_types_reflect_Attribute$sub_refs	polyglot_types_reflect_Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Exceptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_Exceptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_Attribute$sub_nonrefs	polyglot_types_reflect_Attribute;
    _jc_polyglot_types_reflect_Exceptions$sub_nonrefs	polyglot_types_reflect_Exceptions;
};

// Object instance structure
struct _jc_polyglot_types_reflect_Exceptions$object {
	_jc_polyglot_types_reflect_Exceptions$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_Exceptions$vtype	*vtype;
	_jc_polyglot_types_reflect_Exceptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_Exceptions$vtype _jc_polyglot_types_reflect_Exceptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_Exceptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_Exceptions$class_object;

#endif	/* _JC_polyglot_types_reflect_Exceptions_H_ */
